{
  "cells": [
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# 1st ITSTGCN\n",
        "\n",
        "GUEBIN CHOI  \n",
        "2023-02-15\n",
        "\n",
        "> GNAR fiveNet,fivenodes lag 1\n",
        "\n",
        "# import"
      ],
      "id": "74502612-f3fc-406f-97b6-41c7ca86f451"
    },
    {
      "cell_type": "code",
      "execution_count": 1,
      "metadata": {},
      "outputs": [],
      "source": [
        "import numpy as np\n",
        "import pandas as pd\n",
        "import matplotlib.pyplot as plt\n",
        "from matplotlib import animation\n",
        "\n",
        "# torch\n",
        "import torch\n",
        "import torch.nn.functional as F\n",
        "import torch_geometric_temporal\n",
        "from torch_geometric_temporal.nn.recurrent import GConvGRU\n",
        "\n",
        "# scipy \n",
        "from scipy.interpolate import interp1d\n",
        "\n",
        "# utils\n",
        "import time\n",
        "import pickle\n",
        "from tqdm import tqdm\n",
        "\n",
        "# rpy2\n",
        "import rpy2\n",
        "import rpy2.robjects as ro \n",
        "from rpy2.robjects.vectors import FloatVector\n",
        "import rpy2.robjects as robjects\n",
        "from rpy2.robjects.packages import importr\n",
        "\n",
        "import rpy2.robjects.numpy2ri as rpyn"
      ],
      "id": "f90af573-4bc0-4c9e-ad94-e9739160055e"
    },
    {
      "cell_type": "code",
      "execution_count": 2,
      "metadata": {},
      "outputs": [],
      "source": [
        "class RecurrentGCN(torch.nn.Module):\n",
        "    def __init__(self, node_features, filters):\n",
        "        super(RecurrentGCN, self).__init__()\n",
        "        self.recurrent = GConvGRU(node_features, filters, 2)\n",
        "        self.linear = torch.nn.Linear(filters, 1)\n",
        "\n",
        "    def forward(self, x, edge_index, edge_weight):\n",
        "        h = self.recurrent(x, edge_index, edge_weight)\n",
        "        h = F.relu(h)\n",
        "        h = self.linear(h)\n",
        "        return h"
      ],
      "id": "dbbe91df-66c9-46da-abf9-379f37061d5e"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# my functions"
      ],
      "id": "af9fcf30-0111-40f5-b791-8f996c9f579f"
    },
    {
      "cell_type": "code",
      "execution_count": 3,
      "metadata": {},
      "outputs": [],
      "source": [
        "def load_data(fname):\n",
        "    with open(fname, 'rb') as outfile:\n",
        "        data_dict = pickle.load(outfile)\n",
        "    return data_dict"
      ],
      "id": "227faf0a-4609-4fb1-bb57-f72308e2b23d"
    },
    {
      "cell_type": "code",
      "execution_count": 4,
      "metadata": {},
      "outputs": [],
      "source": [
        "def save_data(data_dict,fname):\n",
        "    with open(fname,'wb') as outfile:\n",
        "        pickle.dump(data_dict,outfile)"
      ],
      "id": "a159f970-32cf-4719-b3b7-d16eeb939f5e"
    },
    {
      "cell_type": "code",
      "execution_count": 5,
      "metadata": {},
      "outputs": [],
      "source": [
        "def plot(f,*args,t=None,h=2.5,**kwargs):\n",
        "    T,N = f.shape\n",
        "    if t == None: t = range(T)\n",
        "    fig = plt.figure()\n",
        "    ax = fig.subplots(N,1)\n",
        "    for n in range(N):\n",
        "        ax[n].plot(t,f[:,n],*args,**kwargs)\n",
        "        ax[n].set_title('node='+str(n))\n",
        "    fig.set_figheight(N*h)\n",
        "    fig.tight_layout()\n",
        "    plt.close()\n",
        "    return fig"
      ],
      "id": "46b2f8de-d7db-4a8a-8b56-68987ea54c0e"
    },
    {
      "cell_type": "code",
      "execution_count": 6,
      "metadata": {},
      "outputs": [],
      "source": [
        "def plot_add(fig,f,*args,t=None,**kwargs):\n",
        "    T = f.shape[0]\n",
        "    N = f.shape[1] \n",
        "    if t == None: t = range(T)   \n",
        "    ax = fig.get_axes()\n",
        "    for n in range(N):\n",
        "        ax[n].plot(t,f[:,n],*args,**kwargs)\n",
        "    return fig"
      ],
      "id": "dfd30cd2-1daf-474d-b132-7b41af02e5f5"
    },
    {
      "cell_type": "code",
      "execution_count": 7,
      "metadata": {},
      "outputs": [],
      "source": [
        "def make_Psi(T):\n",
        "    W = np.zeros((T,T))\n",
        "    for i in range(T):\n",
        "        for j in range(T):\n",
        "            if i==j :\n",
        "                W[i,j] = 0\n",
        "            elif np.abs(i-j) <= 1 : \n",
        "                W[i,j] = 1\n",
        "    d = np.array(W.sum(axis=1))\n",
        "    D = np.diag(d)\n",
        "    L = np.array(np.diag(1/np.sqrt(d)) @ (D-W) @ np.diag(1/np.sqrt(d)))\n",
        "    lamb, Psi = np.linalg.eigh(L)\n",
        "    return Psi"
      ],
      "id": "5422d968-a917-483b-8e82-4ab2bf569bc5"
    },
    {
      "cell_type": "code",
      "execution_count": 8,
      "metadata": {},
      "outputs": [],
      "source": [
        "ebayesthresh = importr('EbayesThresh').ebayesthresh"
      ],
      "id": "6fdbd67c-4d90-4d7f-9a4f-2f73dac5485c"
    },
    {
      "cell_type": "code",
      "execution_count": 9,
      "metadata": {},
      "outputs": [],
      "source": [
        "def trim(f):\n",
        "    f = np.array(f)\n",
        "    if len(f.shape)==1: f = f.reshape(-1,1)\n",
        "    T,N = f.shape\n",
        "    Psi = make_Psi(T)\n",
        "    fbar = Psi.T @ f # apply dft \n",
        "    fbar_threshed = np.stack([ebayesthresh(FloatVector(fbar[:,i])) for i in range(N)],axis=1)\n",
        "    fhat = Psi @ fbar_threshed # inverse dft \n",
        "    return fhat"
      ],
      "id": "7da0eb4f-5518-4e35-b392-9762da230d53"
    },
    {
      "cell_type": "code",
      "execution_count": 10,
      "metadata": {},
      "outputs": [],
      "source": [
        "def update_from_freq_domain(signal, missing_index):\n",
        "    signal = np.array(signal)\n",
        "    T,N = signal.shape \n",
        "    signal_trimed = trim(signal)\n",
        "    for i in range(N):\n",
        "        signal[missing_index[i],i] = signal_trimed[missing_index[i],i]\n",
        "    return signal"
      ],
      "id": "3036d47a-8211-4f46-9cd3-c316e01e5dce"
    },
    {
      "cell_type": "code",
      "execution_count": 11,
      "metadata": {},
      "outputs": [],
      "source": [
        "class DatasetLoader(object):\n",
        "    def __init__(self,data_dict):\n",
        "        self._dataset = data_dict \n",
        "\n",
        "    def _get_edges(self):\n",
        "        self._edges = np.array(self._dataset[\"edges\"]).T\n",
        "\n",
        "    def _get_edge_weights(self):\n",
        "        self._edge_weights = np.ones(self._edges.shape[1])\n",
        "\n",
        "    def _get_targets_and_features(self):\n",
        "        stacked_target = np.array(self._dataset[\"FX\"])\n",
        "        self.features = [\n",
        "            stacked_target[i : i + self.lags, :].T\n",
        "            for i in range(stacked_target.shape[0] - self.lags)\n",
        "        ]\n",
        "        self.targets = [\n",
        "            stacked_target[i + self.lags, :].T\n",
        "            for i in range(stacked_target.shape[0] - self.lags)\n",
        "        ]\n",
        "\n",
        "    def get_dataset(self, lags: int = 4) -> torch_geometric_temporal.signal.StaticGraphTemporalSignal:\n",
        "        \"\"\"Returning the Chickenpox Hungary data iterator.\n",
        "\n",
        "        Args types:\n",
        "            * **lags** *(int)* - The number of time lags.\n",
        "        Return types:\n",
        "            * **dataset** *(torch_geometric_temporal.signal.StaticGraphTemporalSignal)* - The Chickenpox Hungary dataset.\n",
        "        \"\"\"\n",
        "        self.lags = lags\n",
        "        self._get_edges()\n",
        "        self._get_edge_weights()\n",
        "        self._get_targets_and_features()\n",
        "        dataset = torch_geometric_temporal.signal.StaticGraphTemporalSignal(\n",
        "            self._edges, self._edge_weights, self.features, self.targets\n",
        "        )\n",
        "        return dataset"
      ],
      "id": "fb23441c-3d39-4474-819e-e6af810bdce5"
    },
    {
      "cell_type": "code",
      "execution_count": 12,
      "metadata": {},
      "outputs": [],
      "source": [
        "def stgcn(train_dataset,lags=1,filters=32,epoch=50): \n",
        "    model = RecurrentGCN(node_features=lags, filters=filters)\n",
        "    optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "    model.train()\n",
        "\n",
        "    for epoch in tqdm(range(epoch)):\n",
        "        for t, snapshot in enumerate(train_dataset):\n",
        "            yt_hat = model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "            cost = torch.mean((yt_hat-snapshot.y)**2)\n",
        "            cost.backward()\n",
        "            optimizer.step()\n",
        "            optimizer.zero_grad()\n",
        "    return model "
      ],
      "id": "be84173e-663d-4529-b70d-26d6427a04a5"
    },
    {
      "cell_type": "code",
      "execution_count": 13,
      "metadata": {},
      "outputs": [],
      "source": [
        "%load_ext rpy2.ipython"
      ],
      "id": "8381f21a-b8da-4ed7-befb-a308868ad854"
    },
    {
      "cell_type": "code",
      "execution_count": 14,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "R[write to console]: Loading required package: igraph\n",
            "\n",
            "R[write to console]: \n",
            "Attaching package: ‘igraph’\n",
            "\n",
            "\n",
            "R[write to console]: The following objects are masked from ‘package:stats’:\n",
            "\n",
            "    decompose, spectrum\n",
            "\n",
            "\n",
            "R[write to console]: The following object is masked from ‘package:base’:\n",
            "\n",
            "    union\n",
            "\n",
            "\n",
            "R[write to console]: Loading required package: wordcloud\n",
            "\n",
            "R[write to console]: Loading required package: RColorBrewer\n",
            "\n",
            "R[write to console]: \n",
            "Attaching package: ‘zoo’\n",
            "\n",
            "\n",
            "R[write to console]: The following objects are masked from ‘package:base’:\n",
            "\n",
            "    as.Date, as.Date.numeric\n",
            "\n"
          ]
        }
      ],
      "source": [
        "%%R\n",
        "library(GNAR)\n",
        "library(igraph)\n",
        "library(zoo)"
      ],
      "id": "5b2acf2d-e0ae-4857-99a4-7b9d174fae9b"
    },
    {
      "cell_type": "code",
      "execution_count": 15,
      "metadata": {},
      "outputs": [],
      "source": [
        "%%R\n",
        "fiveNet_m <- as.matrix(fiveNet)"
      ],
      "id": "d054b87d-a1a2-471d-98df-15012606960e"
    },
    {
      "cell_type": "code",
      "execution_count": 16,
      "metadata": {},
      "outputs": [],
      "source": [
        "%R -o fiveNet_m"
      ],
      "id": "b3966f3d-fcc4-4568-a2b1-ba12e653ff3d"
    },
    {
      "cell_type": "code",
      "execution_count": 17,
      "metadata": {},
      "outputs": [],
      "source": [
        "GNAR = importr('GNAR') # import GNAR \n",
        "igraph = importr('igraph') # import igraph "
      ],
      "id": "bd6da55e-9f1a-4e73-b7cc-111ee5c36d75"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# data 정리\n",
        "\n",
        "`-` 데이터정리"
      ],
      "id": "6425e464-05fb-46f8-8cf0-05e4ca2816c1"
    },
    {
      "cell_type": "code",
      "execution_count": 24,
      "metadata": {},
      "outputs": [],
      "source": [
        "_data = load_data('./data/fivenodes.pkl')"
      ],
      "id": "0bcaefae-0b23-4dbd-b35b-30a36b84095b"
    },
    {
      "cell_type": "code",
      "execution_count": 25,
      "metadata": {},
      "outputs": [],
      "source": [
        "_edges = torch.tensor(_data['edges']).nonzero().tolist()\n",
        "_FX = _data['f'].tolist()\n",
        "_node_ids = {'node1':0, 'node2':1, 'node3':2, 'node4':3, 'node5':4} "
      ],
      "id": "1d9e6a2e-50bd-48db-a618-8b7220620cd1"
    },
    {
      "cell_type": "code",
      "execution_count": 26,
      "metadata": {},
      "outputs": [],
      "source": [
        "data_dict = {'edges':_edges, 'node_ids':_node_ids, 'FX':_FX}"
      ],
      "id": "811ed64e-1e1d-4249-8903-8800fbf864ff"
    },
    {
      "cell_type": "code",
      "execution_count": 346,
      "metadata": {},
      "outputs": [],
      "source": [
        "train_dataset.edge_index.T.tolist()"
      ],
      "id": "220b7740-bc0a-4c7d-952f-ba26101053a4"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "train_dataset."
      ],
      "id": "69debca4-0a4e-4a69-9db6-9959ce5dd9ed"
    },
    {
      "cell_type": "code",
      "execution_count": 336,
      "metadata": {},
      "outputs": [],
      "source": [
        "loader = DatasetLoader(data_dict)\n",
        "dataset = loader.get_dataset(lags=4)\n",
        "train_dataset, test_dataset = torch_geometric_temporal.signal.temporal_signal_split(dataset, train_ratio=0.8)"
      ],
      "id": "cdd39061-1cae-4c94-b710-c3ee79372943"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "`-` STGCN 수행"
      ],
      "id": "65257c8e-2a22-4187-aa72-4c4aa2b4fc1f"
    },
    {
      "cell_type": "code",
      "execution_count": 262,
      "metadata": {},
      "outputs": [],
      "source": [
        "class StgcnLearner:\n",
        "    def __init__(self,train_dataset):\n",
        "        self.train_dataset = train_dataset\n",
        "        self.lags = torch.tensor(train_dataset.features).shape[-1]\n",
        "    def learn(self,filters=32,epoch=50):\n",
        "        self.model = RecurrentGCN(node_features=self.lags, filters=filters)\n",
        "        self.optimizer = torch.optim.Adam(self.model.parameters(), lr=0.01)\n",
        "        self.model.train()\n",
        "        for epoch in tqdm(range(epoch)):\n",
        "            for t, snapshot in enumerate(self.train_dataset):\n",
        "                yt_hat = self.model(snapshot.x, snapshot.edge_index, snapshot.edge_attr)\n",
        "                cost = torch.mean((yt_hat-snapshot.y)**2)\n",
        "                cost.backward()\n",
        "                self.optimizer.step()\n",
        "                self.optimizer.zero_grad()\n",
        "    def __call__(self,dataset):\n",
        "        X = torch.tensor(dataset.features).float()\n",
        "        y = torch.tensor(dataset.targets).float()\n",
        "        yhat = torch.stack([self.model(snapshot.x, snapshot.edge_index, snapshot.edge_attr) for snapshot in dataset]).detach().squeeze().float()\n",
        "        return {'X':X, 'y':y, 'yhat':yhat} "
      ],
      "id": "2db00ced-ef8e-46ee-981d-78d51a8228a4"
    },
    {
      "cell_type": "code",
      "execution_count": 157,
      "metadata": {},
      "outputs": [],
      "source": [
        "lrnr = StgcnLearner(train_dataset)"
      ],
      "id": "84462f81-f846-4ef9-83e5-6d7a68d60b67"
    },
    {
      "cell_type": "code",
      "execution_count": 158,
      "metadata": {},
      "outputs": [
        {
          "output_type": "stream",
          "name": "stderr",
          "text": [
            "100%|██████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████| 1/1 [00:01<00:00,  1.62s/it]"
          ]
        }
      ],
      "source": [
        "lrnr.learn(filters=32,epoch=1)"
      ],
      "id": "3b30279d-76c2-45d6-ab8a-21deea8c7e50"
    },
    {
      "cell_type": "code",
      "execution_count": 160,
      "metadata": {},
      "outputs": [],
      "source": [
        "rslt = lrnr(dataset)"
      ],
      "id": "fc42f6c8-ef9b-4a32-9c52-2e8caffea310"
    },
    {
      "cell_type": "code",
      "execution_count": 263,
      "metadata": {},
      "outputs": [],
      "source": [
        "class Evaluator:\n",
        "    def __init__(self,learner,train_dataset,test_dataset):\n",
        "        self.learner = learner\n",
        "        self.train_dataset = train_dataset\n",
        "        self.test_dataset = test_dataset\n",
        "        self.lags = lrnr.lags\n",
        "        rslt_tr = self.learner(self.train_dataset) \n",
        "        rslt_test = self.learner(self.test_dataset)\n",
        "        self.X_tr = rslt_tr['X']\n",
        "        self.y_tr = rslt_tr['y']\n",
        "        self.f_tr = torch.concat([self.train_dataset[0].x.T,self.y_tr],axis=0).float()\n",
        "        self.yhat_tr = rslt_tr['yhat']\n",
        "        self.fhat_tr = torch.concat([self.train_dataset[0].x.T,self.yhat_tr],axis=0).float()\n",
        "        self.X_test = rslt_test['X']\n",
        "        self.y_test = rslt_test['y']\n",
        "        self.f_test = self.y_test \n",
        "        self.yhat_test = rslt_test['yhat']\n",
        "        self.fhat_test = self.yhat_test\n",
        "        self.f = torch.concat([self.f_tr,self.f_test],axis=0)\n",
        "        self.fhat = torch.concat([self.fhat_tr,self.fhat_test],axis=0)\n",
        "    def calculate_mse(self):\n",
        "        train_mse_eachnode = ((self.y_tr-self.yhat_tr)**2).mean(axis=0).tolist()\n",
        "        train_mse_total = ((self.y_tr-self.yhat_tr)**2).mean().item()\n",
        "        test_mse_eachnode = ((self.y_test-self.yhat_test)**2).mean(axis=0).tolist()\n",
        "        test_mse_total = ((self.y_test-self.yhat_test)**2).mean().item()\n",
        "        self.mse = {'train': {'each_node': train_mse_eachnode, 'total': train_mse_total},\n",
        "                    'test': {'each_node': test_mse_eachnode, 'total': test_mse_total}}\n",
        "    def _plot(self,*args,t=None,h=2.5,max_nodes=5,**kwargs):\n",
        "        T,N = self.f.shape\n",
        "        if N>max_nodes: N=max_nodes\n",
        "        if t == None: t = range(T)\n",
        "        fig = plt.figure()\n",
        "        ax = fig.subplots(N,1)\n",
        "        for n in range(N):\n",
        "            ax[n].plot(t,self.f[:,n],color='gray',*args,**kwargs)\n",
        "            ax[n].set_title('node='+str(n))\n",
        "        fig.set_figheight(N*h)\n",
        "        fig.tight_layout()\n",
        "        plt.close()\n",
        "        return fig\n",
        "    def plot(self,*args,t=None,h=2.5,**kwargs):\n",
        "        self.calculate_mse()\n",
        "        fig = self._plot(*args,t=None,h=2.5,**kwargs)\n",
        "        ax = fig.get_axes()\n",
        "        for i,a in enumerate(ax):\n",
        "            _mse1= self.mse['train']['each_node'][i]\n",
        "            _mse2= self.mse['test']['each_node'][i]\n",
        "            _title = 'node{0} \\n mse(train) = {1:.2f}, mse(test) = {2:.2f}'.format(i,_mse1,_mse2)\n",
        "            a.set_title(_title)\n",
        "            _t1 = self.lags\n",
        "            _t2 = self.yhat_tr.shape[0]+self.lags\n",
        "            _t3 = len(self.f)\n",
        "            a.plot(range(_t1,_t2),self.yhat_tr[:,i],label='STCGCN (train)',color='C0')\n",
        "            a.plot(range(_t2,_t3),self.yhat_test[:,i],label='STCGCN (test)',color='C1')\n",
        "            a.legend()\n",
        "        _mse1 = self.mse['train']['total']\n",
        "        _mse2 = self.mse['test']['total']\n",
        "        fig.suptitle(\"Scenario1: STGCN \\n missing=0% \\n interpolation=None \\n mse(train) = {0:.2f}, mse(test) = {1:.2f} \\n\".format(_mse1,_mse2))\n",
        "        fig.tight_layout()\n",
        "        return fig"
      ],
      "id": "89f8b55a-9109-42df-b6f2-a72dac2b90e9"
    },
    {
      "cell_type": "code",
      "execution_count": 264,
      "metadata": {},
      "outputs": [],
      "source": [
        "evtor = Evaluator(lrnr,train_dataset,test_dataset)"
      ],
      "id": "29730eaf-a396-4ae9-ba9b-9e0a11c65b97"
    },
    {
      "cell_type": "code",
      "execution_count": 265,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAagAAAIUCAYAAABPUrhTAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n"
          }
        }
      ],
      "source": [
        "evtor.plot('--.',h=4,max_nodes=3,label='complete data',alpha=0.5)"
      ],
      "id": "5661d154-d7ee-4e4c-b122-a6711316264c"
    },
    {
      "cell_type": "code",
      "execution_count": 350,
      "metadata": {},
      "outputs": [],
      "source": [
        "FX = torch.concat([train_dataset[0].x.T,torch.tensor(train_dataset.targets)],axis=0).tolist()"
      ],
      "id": "1452a206-e2f3-486c-a0fd-96dbd31f3326"
    },
    {
      "cell_type": "code",
      "execution_count": 356,
      "metadata": {},
      "outputs": [],
      "source": [
        "data_dict['node_ids']"
      ],
      "id": "f264cee4-f022-4108-a0f8-144361642e88"
    },
    {
      "cell_type": "code",
      "execution_count": 359,
      "metadata": {},
      "outputs": [],
      "source": [
        "data_dict.keys()"
      ],
      "id": "bf96c2ef-f8c7-4aa6-9eb7-ce0b4ee579a7"
    },
    {
      "cell_type": "code",
      "execution_count": 369,
      "metadata": {},
      "outputs": [],
      "source": [
        "def miss(train_dataset,missing_rate=0.5):\n",
        "    f = torch.concat([train_dataset[0].x.T,torch.tensor(train_dataset.targets)],axis=0).numpy()\n",
        "    T,N = f.shape\n",
        "    missing_count = int(np.round(missing_rate*T,0))\n",
        "    mindex = [np.sort(np.random.choice(range(T),missing_count,replace=False)).tolist() for i in range(N)]  \n",
        "    for i,m in enumerate(mindex): \n",
        "        f[m,i] = np.nan\n",
        "    FX = f.tolist()\n",
        "    edges = train_dataset.edge_index.T.tolist()\n",
        "    node_ids = {'node'+str(i):i for i in range(N)}\n",
        "    data_dict = {'edges':edges, 'node_ids':node_ids, 'FX':FX} \n",
        "    return f"
      ],
      "id": "e1849667-b3ac-4c0f-b8e2-28df0aeb4378"
    },
    {
      "cell_type": "code",
      "execution_count": 367,
      "metadata": {},
      "outputs": [],
      "source": [
        "f = miss(train_dataset)"
      ],
      "id": "ce97581e-df69-4ac5-adfc-06b6645dc17a"
    },
    {
      "cell_type": "code",
      "execution_count": 368,
      "metadata": {},
      "outputs": [],
      "source": [
        "f.tolist()"
      ],
      "id": "a4592c74-fc71-44f3-9e2c-2a4a2d655fe4"
    },
    {
      "cell_type": "code",
      "execution_count": 328,
      "metadata": {},
      "outputs": [],
      "source": [
        "f"
      ],
      "id": "fd74d3fc-1b09-4113-96f0-5fd28d0180da"
    },
    {
      "cell_type": "code",
      "execution_count": 327,
      "metadata": {},
      "outputs": [],
      "source": [
        "np.stack([f[train_dataset.mindex[i],i] for i in range(N)],axis=1)"
      ],
      "id": "f84253a9-90c2-4333-bb7b-9eb2bfc49b11"
    },
    {
      "cell_type": "code",
      "execution_count": 40,
      "metadata": {},
      "outputs": [],
      "source": [
        "edges_tensor = torch.tensor(data['edges'])\n",
        "fiveVTS = np.array(data['f'])\n",
        "nonzero_indices = edges_tensor.nonzero()\n",
        "fiveNet_edge = np.array(nonzero_indices).T\n",
        "T = 200\n",
        "N = 5 # number of Nodes\n",
        "E = fiveNet_edge\n",
        "V = np.array([1,2,3,4,5])\n",
        "t = np.arange(0,T)\n",
        "node_features = 1\n",
        "edge_index = torch.tensor(E)\n",
        "edge_attr = torch.tensor(np.array([1,1,1,1,1,1,1,1,1,1]),dtype=torch.float32)"
      ],
      "id": "50d881f0-65fc-49c4-acab-1c7b4d371a11"
    },
    {
      "cell_type": "code",
      "execution_count": 42,
      "metadata": {},
      "outputs": [],
      "source": [
        "edge_index"
      ],
      "id": "6ad8e618-8ecd-44ec-b830-a51f043d5c98"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "`-` train / test"
      ],
      "id": "52b235b0-183d-4d16-a080-5bbe01b61beb"
    },
    {
      "cell_type": "code",
      "execution_count": 18,
      "metadata": {},
      "outputs": [],
      "source": [
        "fiveVTS_train = fiveVTS[:int(len(fiveVTS)*0.8)]\n",
        "fiveVTS_test = fiveVTS[int(len(fiveVTS)*0.8):]"
      ],
      "id": "cef13f89-df0c-467f-b856-7145f554e428"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# Random Missing Values"
      ],
      "id": "01ce0cd7-1a20-44f5-b1be-554022b5c581"
    },
    {
      "cell_type": "code",
      "execution_count": 19,
      "metadata": {},
      "outputs": [],
      "source": [
        "class Missing:\n",
        "    def __init__(self,df):\n",
        "        self.df = df\n",
        "        self.N = N\n",
        "        self.number = []\n",
        "    def miss(self,percent=0.5):\n",
        "        self.missing = self.df.copy()\n",
        "        self.percent = percent\n",
        "        for i in range(self.N):\n",
        "            #self.seed = np.random.choice(1000,1,replace=False)\n",
        "            #np.random.seed(self.seed)\n",
        "            self.number.append(np.random.choice(int(len(self.df))-1,int(len(self.df)*self.percent),replace=False))\n",
        "            self.missing[self.number[i],i] = float('nan')\n",
        "    def first_mean(self):\n",
        "        self.train_mean = self.missing.copy()\n",
        "        for i in range(self.N):\n",
        "            self.train_mean[self.number[i],i] = np.nanmean(self.missing[:,i])\n",
        "    def second_linear(self):\n",
        "        self.train_linear = pd.DataFrame(self.missing)\n",
        "        self.train_linear.interpolate(method='linear', inplace=True)\n",
        "        self.train_linear = self.train_linear.fillna(0)\n",
        "        self.train_linear = np.array(self.train_linear).reshape(int(len(self.df)),N)"
      ],
      "id": "a9c2d697-7649-4ed0-a0c7-e4b66c4fd45c"
    },
    {
      "cell_type": "code",
      "execution_count": 20,
      "metadata": {},
      "outputs": [],
      "source": [
        "col = ['Dataset','iteration', 'method', 'missingrate', 'missingtype', 'lag', 'number_of_filters', 'interpolation','MSE_train', 'MSE_test']\n",
        "\n",
        "rate = [i/10 for i in range(10)]"
      ],
      "id": "79dda18e-9e34-4227-806c-431a07403290"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# Class code by Method\n",
        "\n",
        "## STGCN"
      ],
      "id": "d55484cf-b0a1-4f6e-85b7-819f4ab52f61"
    },
    {
      "cell_type": "code",
      "execution_count": 21,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "class STGCN_Missing:\n",
        "    def __init__(self,Dataset,df, iterable, Method, Missingrate, Missingtype, lag, Number_of_filters, Interpolation):\n",
        "        self.Dataset = Dataset\n",
        "        self.df = df\n",
        "        self.iterable = iterable\n",
        "        self.Method = Method\n",
        "        self.Missingrate = Missingrate\n",
        "        self.Missingtype = Missingtype\n",
        "        self.lag = lag\n",
        "        self.Number_of_filters = Number_of_filters\n",
        "        self.Interpolation = Interpolation\n",
        "    def iter(self):\n",
        "        self.XX = torch.tensor(fiveVTS_test.reshape(int(T*0.2),N,1)[:-1,:,:]).float()\n",
        "        self.yy = torch.tensor(fiveVTS_test.reshape(int(T*0.2),N,1)[1:,:,:]).float()\n",
        "\n",
        "        self.real_y = torch.tensor(fiveVTS_train).reshape(int(T*0.8),N,1).float()[1:,:,:]\n",
        "        for i in range(self.iterable):\n",
        "\n",
        "            _zero = Missing(fiveVTS_train)\n",
        "            _zero.miss(percent = self.Missingrate)\n",
        "            _zero.second_linear()\n",
        "\n",
        "            missing_index = _zero.number\n",
        "            interpolated_signal = _zero.train_linear\n",
        "\n",
        "            X = torch.tensor(interpolated_signal).reshape(int(T*0.8),N,1).float()[:int(T*0.8-1),:,:]\n",
        "            y = torch.tensor(interpolated_signal).reshape(int(T*0.8),N,1).float()[1:,:,:]\n",
        "\n",
        "            net = RecurrentGCN(node_features=self.lag, filters=self.Number_of_filters)\n",
        "            optimizer = torch.optim.Adam(net.parameters(), lr=0.01)\n",
        "            net.train()\n",
        "            for epoch in range(50):\n",
        "                for time, (xt,yt) in enumerate(zip(X,y)):\n",
        "                    yt_hat = net(xt, edge_index, edge_attr)\n",
        "                    cost = torch.mean((yt_hat-yt)**2)\n",
        "                    cost.backward()\n",
        "                    optimizer.step()\n",
        "                    optimizer.zero_grad()\n",
        "\n",
        "            yhat = torch.stack([net(xt, edge_index, edge_attr) for xt in X]).detach().numpy()\n",
        "            yyhat = torch.stack([net(xt, edge_index, edge_attr) for xt in self.XX]).detach().numpy()\n",
        "\n",
        "            train_mse_total_stgcn = (((self.real_y-yhat).squeeze())**2).mean()\n",
        "            test_mse_total_stgcn = (((self.yy-yyhat).squeeze())**2).mean() \n",
        "\n",
        "            df_row = pd.DataFrame(columns=col)\n",
        "            df_row['Dataset'] = self.Dataset, \n",
        "            df_row['iteration'] = i+1, # 1,2,3,...,10 \n",
        "            df_row['method'] = self.Method, # 'stgcn','estgcn','gnar' \n",
        "            df_row['missingrate'] = self.Missingrate, # 0.0, 0.2, 0.4, 0.6, 0.8 \n",
        "            df_row['missingtype'] = self.Missingtype,  # None, 'randomly' and 'block' \n",
        "            df_row['lag'] = self.lag, # 1,2,3,4 ... \n",
        "            df_row['number_of_filters'] = self.Number_of_filters, # 16,24,32, ... \n",
        "            df_row['interpolation'] = self.Interpolation, # None, 'mean', 'linear'\n",
        "            df_row['MSE_train'] = train_mse_total_stgcn.tolist()\n",
        "            df_row['MSE_test'] = test_mse_total_stgcn.tolist()\n",
        "\n",
        "            self.df = pd.concat([self.df,df_row])"
      ],
      "id": "3e4cefbf-1ffb-481f-9084-42d90689956f"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Enhencement of STGCN"
      ],
      "id": "d23ca2e2-39b4-495b-a7f0-dc51f4d34ffb"
    },
    {
      "cell_type": "code",
      "execution_count": 22,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "class ESTGCN_Missing:\n",
        "    def __init__(self,Dataset,df, iterable, Method, Missingrate, Missingtype, lag, Number_of_filters, Interpolation):\n",
        "        self.Dataset = Dataset\n",
        "        self.df = df\n",
        "        self.iterable = iterable\n",
        "        self.Method = Method\n",
        "        self.Missingrate = Missingrate\n",
        "        self.Missingtype = Missingtype\n",
        "        self.lag = lag\n",
        "        self.Number_of_filters = Number_of_filters\n",
        "        self.Interpolation = Interpolation\n",
        "    def iter(self):\n",
        "        self.XX = torch.tensor(fiveVTS_test.reshape(int(T*0.2),N,1)[:-1,:,:]).float()\n",
        "        self.yy = torch.tensor(fiveVTS_test.reshape(int(T*0.2),N,1)[1:,:,:]).float()\n",
        "\n",
        "        self.real_y = torch.tensor(fiveVTS_train).reshape(int(T*0.8),N,1).float()[1:,:,:]\n",
        "        for i in range(self.iterable):\n",
        "    \n",
        "            _zero = Missing(fiveVTS_train)\n",
        "            _zero.miss(percent = self.Missingrate)\n",
        "            _zero.second_linear()\n",
        "\n",
        "            missing_index = _zero.number\n",
        "            interpolated_signal = _zero.train_linear\n",
        "\n",
        "            X = torch.tensor(interpolated_signal).reshape(int(T*0.8),N,1).float()[:int(T*0.8-1),:,:]\n",
        "            y = torch.tensor(interpolated_signal).reshape(int(T*0.8),N,1).float()[1:,:,:]\n",
        "\n",
        "\n",
        "            net = RecurrentGCN(node_features=self.lag, filters=self.Number_of_filters)\n",
        "            optimizer = torch.optim.Adam(net.parameters(), lr=0.01)\n",
        "            net.train()\n",
        "            signal = interpolated_signal.copy()\n",
        "            for epoch in range(50):\n",
        "                signal = update_from_freq_domain(signal,missing_index)\n",
        "                X = torch.tensor(signal).reshape(int(T*0.8),N,1).float()[:int(T*0.8-1),:,:]\n",
        "                y = torch.tensor(signal).reshape(int(T*0.8),N,1).float()[1:,:,:]\n",
        "                for time, (xt,yt) in enumerate(zip(X,y)):        \n",
        "                    yt_hat = net(xt, edge_index, edge_attr)\n",
        "                    cost = torch.mean((yt_hat-yt)**2)\n",
        "                    cost.backward()\n",
        "                    optimizer.step()\n",
        "                    optimizer.zero_grad()\n",
        "                signal = torch.concat([X.squeeze(),yt_hat.detach().squeeze().reshape(1,-1)])               \n",
        "\n",
        "            yhat = torch.stack([net(xt, edge_index, edge_attr) for xt in X]).detach().numpy()\n",
        "            yyhat = torch.stack([net(xt, edge_index, edge_attr) for xt in self.XX]).detach().numpy()\n",
        "\n",
        "            train_mse_total_estgcn = (((self.real_y-yhat).squeeze())**2).mean()\n",
        "            test_mse_total_estgcn = (((self.yy-yyhat).squeeze())**2).mean()\n",
        "\n",
        "            df_row = pd.DataFrame(columns=col)\n",
        "            df_row['Dataset'] = self.Dataset,\n",
        "            df_row['iteration'] = i+1, # 1,2,3,...,10 \n",
        "            df_row['method'] = self.Method, # 'stgcn','estgcn','gnar' \n",
        "            df_row['missingrate'] = self.Missingrate, # 0.0, 0.2, 0.4, 0.6, 0.8 \n",
        "            df_row['missingtype'] = self.Missingtype,  # None, 'randomly' and 'block' \n",
        "            df_row['lag'] = self.lag, # 1,2,3,4 ... \n",
        "            df_row['number_of_filters'] = self.Number_of_filters, # 16,24,32, ... \n",
        "            df_row['interpolation'] = self.Interpolation, # None, 'mean', 'linear'\n",
        "            df_row['MSE_train'] = train_mse_total_estgcn.tolist()\n",
        "            df_row['MSE_test'] = test_mse_total_estgcn.tolist()\n",
        "\n",
        "            self.df = pd.concat([self.df,df_row])"
      ],
      "id": "532d3cd3-ba47-4747-9933-98dfd5d44bd2"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## GNAR"
      ],
      "id": "67c68770-f27d-4e80-80b4-c3d0b483ba5e"
    },
    {
      "cell_type": "code",
      "execution_count": 23,
      "metadata": {},
      "outputs": [],
      "source": [
        "m = robjects.r.matrix(FloatVector([0,0,0,1,1,0,0,1,1,0,0,1,0,1,0,1,1,1,0,0,1,0,0,0,0]), nrow = 5, ncol = 5)"
      ],
      "id": "ff49ecf4-a1a8-43fe-b72f-71f407ffdad1"
    },
    {
      "cell_type": "code",
      "execution_count": 24,
      "metadata": {
        "tags": []
      },
      "outputs": [],
      "source": [
        "class GNAR_Missing:\n",
        "    def __init__(self,Dataset,df, iterable, Method, Missingrate, Missingtype, lag, Number_of_filters, Interpolation):\n",
        "        self.Dataset = Dataset\n",
        "        self.df = df\n",
        "        self.iterable = iterable\n",
        "        self.Method = Method\n",
        "        self.Missingrate = Missingrate\n",
        "        self.Missingtype = Missingtype\n",
        "        self.lag = lag\n",
        "        self.Number_of_filters = Number_of_filters\n",
        "        self.Interpolation = Interpolation\n",
        "    def iter(self):\n",
        "        self.yy = torch.tensor(fiveVTS_test.reshape(int(T*0.2),N,1)[1:,:,:]).float()\n",
        "        for i in range(self.iterable):\n",
        "\n",
        "            _zero = Missing(fiveVTS_train)\n",
        "            _zero.miss(percent = self.Missingrate)\n",
        "            _zero.second_linear()\n",
        "\n",
        "            missing_index = _zero.number\n",
        "            interpolated_signal = _zero.train_linear\n",
        "\n",
        "            X = torch.tensor(interpolated_signal).reshape(int(T*0.8),N,1).float()[:int(T*0.8-2),:,:]\n",
        "\n",
        "            answer = GNAR.GNARfit(vts=robjects.r.matrix(rpyn.numpy2rpy(np.array(X).squeeze()), nrow = 160, ncol = 5),net = GNAR.matrixtoGNAR(m), alphaOrder = 2, betaOrder = FloatVector([1, 1]))             \n",
        "            predict = GNAR.predict_GNARfit(answer,n_ahead=40)\n",
        "\n",
        "\n",
        "            train_mse_total_gnar = ((pd.DataFrame(GNAR.residuals_GNARfit(answer)).values.reshape(-1,5))**2).mean()\n",
        "            test_mse_total_gnar = ((self.yy.squeeze() - pd.DataFrame(predict).values.reshape(-1,5)[:-1,:])**2).mean()\n",
        "\n",
        "            df_row = pd.DataFrame(columns=col)\n",
        "            df_row['Dataset'] = self.Dataset,\n",
        "            df_row['iteration'] = i+1, # 1,2,3,...,10 \n",
        "            df_row['method'] = self.Method, # 'stgcn','estgcn','gnar' \n",
        "            df_row['missingrate'] = self.Missingrate, # 0.0, 0.2, 0.4, 0.6, 0.8 \n",
        "            df_row['missingtype'] = self.Missingtype,  # None, 'randomly' and 'block' \n",
        "            df_row['lag'] = self.lag, # 1,2,3,4 ... \n",
        "            df_row['number_of_filters'] = self.Number_of_filters, # 16,24,32, ... \n",
        "            df_row['interpolation'] = self.Interpolation, # None, 'mean', 'linear'\n",
        "            df_row['MSE_train'] = train_mse_total_gnar.tolist()\n",
        "            df_row['MSE_test'] = test_mse_total_gnar.tolist()\n",
        "\n",
        "            self.df = pd.concat([self.df,df_row])"
      ],
      "id": "a9195dd3-fa73-4ac3-bde9-632666258ae4"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## STGCN"
      ],
      "id": "818dc7fd-f946-4e11-98b9-ee8c41d8ed50"
    },
    {
      "cell_type": "code",
      "execution_count": 25,
      "metadata": {},
      "outputs": [],
      "source": [
        "Dataset = 'fivenodes'\n",
        "Method = 'stgcn' # 'stgcn','estgcn','gnar' \n",
        "Missingtype = 'randomly'  # None, 'randomly' and 'block' \n",
        "lag = 1 # 1,2,3,4 ... \n",
        "Number_of_filters = 4 # 16,24,32, ... \n",
        "Interpolation = 'Linear' # None, 'mean', 'linear'\n",
        "iterable = 100"
      ],
      "id": "45f09158-75e2-4333-a3b3-2a6badfe5e34"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "df_stgcn= pd.DataFrame(columns=col)"
      ],
      "id": "1485dd96-fb2d-4990-8c98-09c8b0c55de7"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "for Missingrate in rate:\n",
        "    df = pd.DataFrame(columns=col)\n",
        "    stgcn = STGCN_Missing(Dataset,df, iterable,Method, Missingrate, Missingtype, lag, Number_of_filters, Interpolation)\n",
        "    stgcn.iter()\n",
        "    df_add = stgcn.df.copy()\n",
        "    df_stgcn = pd.concat([df_stgcn,df_add],axis=0)"
      ],
      "id": "058eb399-56aa-420c-b93f-63eb5f05f77e"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "save_data(df_stgcn, './data/GNAR_stgcn_randomly_by_rate.pkl')"
      ],
      "id": "190fdacf-ec1c-48a6-beb5-fd11a796f31b"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Enhencement of STGCN"
      ],
      "id": "83f31d62-f869-49d0-a17b-b66c859998b4"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "Dataset = 'fivenodes'\n",
        "Method = 'estgcn' # 'stgcn','estgcn','gnar' \n",
        "Missingtype = 'randomly'  # None, 'randomly' and 'block' \n",
        "lag = 1 # 1,2,3,4 ... \n",
        "Number_of_filters = 4 # 16,24,32, ... \n",
        "Interpolation = 'Linear' # None, 'mean', 'linear'\n",
        "iterable = 100"
      ],
      "id": "a13cd97c-8222-495f-8db5-677bf8f3daf6"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "df_estgcn = pd.DataFrame(columns=col)"
      ],
      "id": "ec31e136-0a49-4458-886c-58d0c9c1df9c"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "for Missingrate in rate:\n",
        "    df = pd.DataFrame(columns=col)\n",
        "    estgcn = ESTGCN_Missing(Dataset,df, iterable,Method, Missingrate, Missingtype, lag, Number_of_filters, Interpolation)\n",
        "    estgcn.iter()\n",
        "    df_add = estgcn.df.copy()\n",
        "    df_estgcn = pd.concat([df_estgcn,df_add],axis=0)"
      ],
      "id": "45666064-15c0-4f38-a1da-137c089457d7"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "save_data(df_estgcn, './data/GNAR_estgcn_randomly_by_rate.pkl')"
      ],
      "id": "cc1125a4-a55b-472d-a728-dcc5103e24e3"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## GNAR"
      ],
      "id": "1fab1cc1-4484-47a1-8444-0b3a769c48c2"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "Dataset = 'fivenodes'\n",
        "Method = 'gnar' # 'stgcn','estgcn','gnar' \n",
        "Missingtype = 'randomly'  # None, 'randomly' and 'block' \n",
        "lag = 1 # 1,2,3,4 ... \n",
        "Number_of_filters = None # 16,24,32, ... \n",
        "Interpolation = 'Linear' # None, 'mean', 'linear'\n",
        "iterable = 100"
      ],
      "id": "de1797d2-bb65-408e-bcd1-044aa6dbe923"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "df_gnar = pd.DataFrame(columns=col)"
      ],
      "id": "86a6c8cb-49ec-4557-8b57-2485caacd05d"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "for Missingrate in rate:\n",
        "    df = pd.DataFrame(columns=col)\n",
        "    gnar = GNAR_Missing(Dataset,df, iterable,Method, Missingrate, Missingtype, lag, Number_of_filters, Interpolation)\n",
        "    gnar.iter()\n",
        "    df_add = gnar.df.copy()\n",
        "    df_gnar = pd.concat([df_gnar,df_add],axis=0)"
      ],
      "id": "49336ba8-01d4-457e-b241-405a4f686a4f"
    },
    {
      "cell_type": "code",
      "execution_count": null,
      "metadata": {},
      "outputs": [],
      "source": [
        "save_data(df_gnar, './data/GANR_gnar_randomly_by_rate.pkl')"
      ],
      "id": "1f4d3d89-680d-4286-b32f-322839759320"
    }
  ],
  "nbformat": 4,
  "nbformat_minor": 5,
  "metadata": {
    "kernelspec": {
      "name": "python3",
      "display_name": "Python 3 (ipykernel)",
      "language": "python"
    },
    "language_info": {
      "name": "python",
      "codemirror_mode": {
        "name": "ipython",
        "version": "3"
      },
      "file_extension": ".py",
      "mimetype": "text/x-python",
      "nbconvert_exporter": "python",
      "pygments_lexer": "ipython3",
      "version": "3.8.12"
    },
    "toc-showcode": false
  }
}